protologpb

package
v0.0.0-...-146e201 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 9, 2016 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package protologpb is a generated protocol buffer package.

It is generated from these files:

pb/protologpb.proto

It has these top-level messages:

Entry

Index

Constants

This section is empty.

Variables

var Level_name = map[int32]string{
	0: "LEVEL_NONE",
	1: "LEVEL_DEBUG",
	2: "LEVEL_INFO",
	3: "LEVEL_WARN",
	4: "LEVEL_ERROR",
	5: "LEVEL_FATAL",
	6: "LEVEL_PANIC",
}
var Level_value = map[string]int32{
	"LEVEL_NONE":  0,
	"LEVEL_DEBUG": 1,
	"LEVEL_INFO":  2,
	"LEVEL_WARN":  3,
	"LEVEL_ERROR": 4,
	"LEVEL_FATAL": 5,
	"LEVEL_PANIC": 6,
}

Functions

This section is empty.

Types

type Entry

type Entry struct {
	// id may not be set depending on logger options
	// it is up to the user to determine if id is required
	Id        string                     `protobuf:"bytes,1,opt,name=id" json:"id,omitempty"`
	Level     Level                      `protobuf:"varint,2,opt,name=level,enum=protolog.Level" json:"level,omitempty"`
	Timestamp *google_protobuf.Timestamp `protobuf:"bytes,3,opt,name=timestamp" json:"timestamp,omitempty"`
	// both context and fields may be set
	Context []*Entry_Message  `protobuf:"bytes,4,rep,name=context" json:"context,omitempty"`
	Fields  map[string]string `` /* 132-byte string literal not displayed */
	// one of event, message, writer_output will be set
	Event        *Entry_Message `protobuf:"bytes,6,opt,name=event" json:"event,omitempty"`
	Message      string         `protobuf:"bytes,7,opt,name=message" json:"message,omitempty"`
	WriterOutput []byte         `protobuf:"bytes,8,opt,name=writer_output,proto3" json:"writer_output,omitempty"`
}

Entry is the object serialized for logging.

func (*Entry) Descriptor

func (*Entry) Descriptor() ([]byte, []int)

func (*Entry) GetContext

func (m *Entry) GetContext() []*Entry_Message

func (*Entry) GetEvent

func (m *Entry) GetEvent() *Entry_Message

func (*Entry) GetFields

func (m *Entry) GetFields() map[string]string

func (*Entry) GetTimestamp

func (m *Entry) GetTimestamp() *google_protobuf.Timestamp

func (*Entry) ProtoMessage

func (*Entry) ProtoMessage()

func (*Entry) Reset

func (m *Entry) Reset()

func (*Entry) String

func (m *Entry) String() string

type Entry_Message

type Entry_Message struct {
	Name  string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
	Value []byte `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
}

Message represents a serialized protobuf message. The name is the name registered with protolog.

func (*Entry_Message) Descriptor

func (*Entry_Message) Descriptor() ([]byte, []int)

func (*Entry_Message) ProtoMessage

func (*Entry_Message) ProtoMessage()

func (*Entry_Message) Reset

func (m *Entry_Message) Reset()

func (*Entry_Message) String

func (m *Entry_Message) String() string

type Level

type Level int32

Level is a logging level.

const (
	// is valid
	Level_LEVEL_NONE  Level = 0
	Level_LEVEL_DEBUG Level = 1
	Level_LEVEL_INFO  Level = 2
	Level_LEVEL_WARN  Level = 3
	Level_LEVEL_ERROR Level = 4
	Level_LEVEL_FATAL Level = 5
	Level_LEVEL_PANIC Level = 6
)

func (Level) EnumDescriptor

func (Level) EnumDescriptor() ([]byte, []int)

func (Level) String

func (x Level) String() string

Jump to